@@ -40,7 +40,7 @@ class RemapMethod(Enum):
 
 
 class ModelMeshEntry(ABC):
-    def __init__(self, mesh_type: ModelType, filename: PathLike):
+    def __init__(self, mesh_type: ModelType, filename: PathLike = None):
         if not isinstance(filename, PurePosixPath):
             filename = PurePosixPath(filename)
 
@@ -48,9 +48,16 @@ class ModelMeshEntry(ABC):
         self.filename = filename
 
     def __str__(self) -> str:
+        if self.filename is not None:
+            directory = self.filename.parent
+            name = self.filename.name
+        else:
+            directory = ''
+            name = ''
+
         return (
-            f' {self.mesh_type.value.lower()}_dir: {self.filename.parent}\n'
-            f' {self.mesh_type.value.lower()}_nam: {self.filename.name}'
+            f' {self.mesh_type.value.lower()}_dir: {directory}\n'
+            f' {self.mesh_type.value.lower()}_nam: {name}'
         )
 
 
@@ -101,14 +108,10 @@ class ModelEntry(ConfigurationEntry, SequenceEntry):
     abstract implementation of a generic model
     """
 
-    def __init__(
-        self, name: str, model_type: ModelType, processors: int, **attributes,
-    ):
-        if model_type is None:
-            model_type = ModelType(name)
+    model_type: ModelType
+    name: str
 
-        self.name = name
-        self.model_type = model_type
+    def __init__(self, processors: int, **attributes):
         self.__processors = processors
 
         self.__start_processor = None
@@ -213,10 +216,14 @@ class ModelEntry(ConfigurationEntry, SequenceEntry):
         return f'{self.__class__.__name__}({repr(self.name)}, {self.model_type}, {self.processors}, {", ".join(kwargs)})'
 
     @classmethod
-    def from_string(cls, string: str) -> 'ModelEntry':
+    def from_string(cls, string: str, **kwargs) -> 'ModelEntry':
         lines = string.splitlines()
 
         model_type, name = (value.strip() for value in lines[0].split('_model:'))
+
+        assert ModelType(model_type) == cls.model_type
+        assert name == cls.name
+
         start_processor, end_processor = [
             int(entry) for entry in lines[1].split('_petlist_bounds:')[-1].strip().split()
         ]
@@ -226,11 +233,14 @@ class ModelEntry(ConfigurationEntry, SequenceEntry):
             key, value = (value.strip() for value in attribute_line.split('='))
             attributes[key] = value
 
+        if issubclass(cls, ModelMeshEntry):
+            if 'filename' not in kwargs:
+                kwargs['filename'] = None
+
         return cls(
-            name=name,
-            model_type=ModelType(model_type),
             processors=end_processor + 1 - start_processor,
             **attributes,
+            **kwargs,
         )
 
 
@@ -268,18 +278,29 @@ class ConnectionEntry(SequenceEntry):
                 'connection entry should be formatted as `SRC -> DST   :remapMethod=METHOD`'
             )
 
+        source_model = ModelEntry(None)
+        target_model = ModelEntry(None)
+
+        source_model.name = source
+        source_model.model_type = ModelType(source)
+        target_model.name = target
+        target_model.model_type = ModelType(target)
+
         return cls(
-            source=ModelEntry(source, None, None),
-            target=ModelEntry(target, None, None),
+            source=source_model,
+            target=target_model,
             method=method,
         )
 
 
 class MediatorEntry(ModelEntry):
-    def __init__(self, name: str, processors: int = None, **attributes):
+    model_type = ModelType.MEDIATOR
+    name = 'implicit'
+
+    def __init__(self, processors: int = None, **attributes):
         if processors is None:
             processors = 1
-        super().__init__(name, ModelType.MEDIATOR, processors, **attributes)
+        super().__init__(processors, **attributes)
 
 
 class MediationFunctionEntry(SequenceEntry):
